@@ -18,10 +18,8 @@ import pytorch_lightning as pl
 import torchmetrics
 from torch import nn
 
-from deepvision.layers import FusedMBConv
-from deepvision.layers import MBConv
-from deepvision.utils.utils import parse_model_inputs
-from deepvision.utils.utils import same_padding
+from deepvision.layers import FusedMBConv, MBConv
+from deepvision.utils.utils import parse_model_inputs, same_padding
 
 
 def _make_divisible(filter_num, width_coefficient, depth_divisor, min_depth):
@@ -57,6 +55,7 @@ class EfficientNetV2PT(pl.LightningModule):
         min_depth=8,
         bn_momentum=0.9,
         activation=nn.SiLU,
+        as_backbone=None,
         blockwise_kernel_sizes=None,
         blockwise_num_repeat=None,
         blockwise_input_filters=None,
@@ -89,6 +88,7 @@ class EfficientNetV2PT(pl.LightningModule):
         self.blockwise_se_ratios = blockwise_se_ratios
         self.blockwise_strides = blockwise_strides
         self.blockwise_conv_type = blockwise_conv_type
+        self.as_backbone = as_backbone
 
         if include_top and classes:
             self.acc = torchmetrics.Accuracy(task="multiclass", num_classes=classes)
@@ -105,9 +105,6 @@ class EfficientNetV2PT(pl.LightningModule):
                 f"Received pooling={self.pooling} and include_top={self.include_top}. "
             )
 
-        if not self.include_top and self.pooling is None:
-            raise ValueError(f"`pooling` must be specified when `include_top=False`.")
-
         stem_out_channels = _make_divisible(
             filter_num=self.blockwise_input_filters[0],
             width_coefficient=self.width_coefficient,
@@ -198,17 +195,22 @@ class EfficientNetV2PT(pl.LightningModule):
         x = self.stem_bn(x)
         x = self.activation()(x)
 
+        outputs = []
         for block in self.blocks:
             x = block(x)
+            outputs.append(x)
         x = self.top_conv(x)
         x = self.top_bn(x)
         x = self.activation()(x)
+        outputs.append(x)
 
         if self.include_top:
             # [B, C, F, F] -> [B, avg C]
             x = nn.AvgPool2d(x.shape[2])(x).flatten(1)
             x = self.top_dense(x)
             x = nn.Softmax(dim=1)(x)
+        elif self.as_backbone:
+            return outputs
         else:
             if self.pooling == "avg":
                 x = nn.AvgPool2d(x.shape[2])(x).flatten(1)
