@@ -16,8 +16,7 @@ import pytorch_lightning as pl
 import torchmetrics
 from torch import nn
 
-from deepvision.layers import PatchingAndEmbedding
-from deepvision.layers import TransformerEncoder
+from deepvision.layers import PatchingAndEmbedding, TransformerEncoder
 from deepvision.utils.utils import parse_model_inputs
 
 
@@ -28,6 +27,7 @@ class ViTPT(pl.LightningModule):
         input_shape=(None, None, 3),
         input_tensor=None,
         pooling=None,
+        as_backbone=None,
         classes=None,
         patch_size=None,
         transformer_layer_num=None,
@@ -37,25 +37,11 @@ class ViTPT(pl.LightningModule):
         mlp_dropout=None,
         attention_dropout=None,
         activation=None,
+        weights=None,
         **kwargs,
     ):
         super().__init__()
 
-        if include_top and not classes:
-            raise ValueError(
-                "If `include_top` is True, you should specify `classes`. "
-                f"Received: classes={classes}"
-            )
-
-        if include_top and pooling:
-            raise ValueError(
-                f"`pooling` must be `None` when `include_top=True`."
-                f"Received pooling={pooling} and include_top={include_top}. "
-            )
-
-        if not include_top and pooling is None:
-            raise ValueError(f"`pooling` must be specified when `include_top=False`.")
-
         self.include_top = include_top
         self.pooling = pooling
         self.classes = classes
@@ -66,11 +52,39 @@ class ViTPT(pl.LightningModule):
         self.mlp_dropout = mlp_dropout
         self.attention_dropout = attention_dropout
         self.activation = activation
+        self.patch_size = patch_size
+        self.as_backbone = as_backbone
 
+        if self.include_top and not self.classes:
+            raise ValueError(
+                "If `include_top` is True, you should specify `classes`. "
+                f"Received: classes={self.classes}"
+            )
+
+        if self.include_top and self.pooling:
+            raise ValueError(
+                f"`pooling` must be `None` when `include_top=True`."
+                f"Received pooling={self.pooling} and include_top={self.include_top}. "
+            )
+
+        if self.include_top and self.as_backbone:
+            raise ValueError(
+                f"`as_backbone` must be `False` when `include_top=True`."
+                f"Received as_backbone={self.as_backbone} and include_top={self.include_top}. "
+            )
+
+        if self.as_backbone and self.classes:
+            raise ValueError(
+                f"`as_backbone` must be `False` when `classes` are set."
+                f"Received as_backbone={self.as_backbone} and classes={self.classes}. "
+            )
+
+        # Enforce (3, 224, 224) for  default weights and then
+        # interpolate for higher resolutions
         self.patching_and_embedding = PatchingAndEmbedding(
             project_dim=project_dim,
             patch_size=patch_size,
-            input_shape=input_shape,
+            input_shape=(3, 224, 224),
             backend="pytorch",
         )
 
@@ -97,19 +111,32 @@ class ViTPT(pl.LightningModule):
     def forward(self, input_tensor):
         inputs = parse_model_inputs("pytorch", input_tensor.shape, input_tensor)
         x = inputs
+        outputs = []
 
-        encoded_patches = self.patching_and_embedding(x)
+        if x.shape != (3, 224, 224):
+            encoded_patches = self.patching_and_embedding(
+                x,
+                interpolate=True,
+                patch_size=self.patch_size,
+                interpolate_height=x.shape[2],
+                interpolate_width=x.shape[3],
+            )
+        else:
+            encoded_patches = self.patching_and_embedding(x)
         x = nn.Dropout(self.mlp_dropout)(encoded_patches)
 
         for transformer_layer in self.transformer_layers:
             x = transformer_layer(x)
+            outputs.append(x)
 
         layer_norm = self.layer_norm(x)
 
         if self.include_top:
-            output = layer_norm.mean(dim=1)
+            output = layer_norm[:, 0]
             output = self.linear(output)
             output = nn.Softmax(dim=1)(output)
+        elif self.as_backbone:
+            return outputs
         else:
             if self.pooling == "avg":
                 output = layer_norm.mean(dim=1)
